@@ -75,7 +75,7 @@ render.sigr_aucpermtest <- function(statistic,
 permTestAUC <- function(d,
                       modelName,
                       yName,
-                      yTarget,
+                      yTarget = TRUE,
                       ...,
                       na.rm= FALSE,
                       returnScores= FALSE,
@@ -177,7 +177,7 @@ render.sigr_aucresamptest <- function(statistic,
 resampleTestAUC <- function(d,
                       modelName,
                       yName,
-                      yTarget,
+                      yTarget = TRUE,
                       ...,
                       na.rm= FALSE,
                       returnScores= FALSE,
@@ -288,7 +288,7 @@ testAUCpair <- function(d,
                         model1Name,
                         model2Name,
                         yName,
-                        yTarget,
+                        yTarget = TRUE,
                         ...,
                         na.rm= FALSE,
                         returnScores= FALSE,
